sequencetools.partition_sequence_by_weights_at_most
===================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_by_weights_at_most.partition_sequence_by_weights_at_most
